@@ -1,7 +1,10 @@
 from enum import Enum
 from typing import Union
 
-from typing_extensions import Literal
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 from ..functions.base import BaseFunction
 from ..properties.constant import Constant
