@@ -2,7 +2,11 @@ from decimal import Decimal
 from typing import Union
 
 from pydantic import validator
-from typing_extensions import Literal
+
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 from ..base import BaseType
 
